@@ -30,10 +30,6 @@
 #include <colord.h>
 #include <math.h>
 
-#ifdef HAVE_CLUTTER
- #include <clutter-gtk/clutter-gtk.h>
-#endif
-
 #include "gcm-cell-renderer-profile-text.h"
 #include "gcm-cell-renderer-color.h"
 #include "gcm-cie-widget.h"
@@ -42,17 +38,12 @@
 #include "gcm-utils.h"
 #include "gcm-debug.h"
 
-#ifdef HAVE_CLUTTER
- #include "gcm-hull-widget.h"
-#endif
-
 typedef struct {
 	GtkBuilder	*builder;
 	GtkApplication	*application;
 	GtkListStore	*list_store_profiles;
 	CdClient	*client;
 	GtkWidget	*cie_widget;
-	GtkWidget	*hull_widget;
 	GtkWidget	*trc_widget;
 	GtkWidget	*vcgt_widget;
 	GtkWidget	*preview_widget_input;
@@ -1063,15 +1054,6 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 		gtk_widget_hide (widget);
 	}
 
-#ifdef HAVE_CLUTTER
-	/* show 3d gamut hull */
-	gtk_widget_show (viewer->hull_widget);
-	gcm_hull_widget_clear (GCM_HULL_WIDGET (viewer->hull_widget));
-	ret = gcm_hull_widget_add (GCM_HULL_WIDGET (viewer->hull_widget), icc);
-	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "vbox_3d"));
-	gtk_widget_set_visible (widget, ret);
-#endif
-
 	/* get vcgt data */
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "vbox_vcgt"));
 	clut_vcgt = cd_icc_get_vcgt (icc, 256, NULL);
@@ -1661,16 +1643,6 @@ gcm_viewer_startup_cb (GApplication *application, GcmViewerPrivate *viewer)
 	gtk_box_pack_start (GTK_BOX(widget), viewer->cie_widget, TRUE, TRUE, 0);
 	gtk_box_reorder_child (GTK_BOX(widget), viewer->cie_widget, 0);
 
-	/* use clutter widget */
-	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "vbox_3d"));
-#ifdef HAVE_CLUTTER
-	viewer->hull_widget = gcm_hull_widget_new ();
-	gtk_box_pack_start (GTK_BOX(widget), viewer->hull_widget, TRUE, TRUE, 0);
-	gtk_box_reorder_child (GTK_BOX(widget), viewer->hull_widget, 0);
-#else
-	gtk_widget_hide (widget);
-#endif
-
 	/* use trc widget */
 	viewer->trc_widget = gcm_trc_widget_new ();
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "vbox_trc_widget"));
@@ -1833,10 +1805,6 @@ main (int argc, char **argv)
 	textdomain (GETTEXT_PACKAGE);
 
 	gtk_init (&argc, &argv);
-#ifdef HAVE_CLUTTER
-	if (gtk_clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS)
-		return 1;
-#endif
 
 	context = g_option_context_new ("gnome-color-manager profile viewer");
 	g_option_context_add_main_entries (context, options, NULL);
